# Generated by Django 3.2.12 on 2022-03-08 01:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cjtmc_base', '0003_env_siteid'),
    ]

    operations = [
        migrations.AddField(
            model_name='idc',
            name='Remark',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='备注信息'),
        ),
    ]
