# Generated by Django 3.2.12 on 2022-03-07 02:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cjtmc_base', '0002_env'),
    ]

    operations = [
        migrations.AddField(
            model_name='env',
            name='SiteId',
            field=models.IntegerField(blank=True, default=1, null=True, verbose_name='租户id'),
        ),
    ]
