# Generated by Django 3.2.12 on 2022-04-15 01:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cjtmc_base', '0005_auto_20220414_0853'),
    ]

    operations = [
        migrations.AddField(
            model_name='origin',
            name='Default',
            field=models.BooleanField(default=False, verbose_name='是否为默认账号'),
        ),
    ]
