# Generated by Django 3.2.12 on 2022-04-14 08:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cjtmc_base', '0004_idc_remark'),
    ]

    operations = [
        migrations.AlterField(
            model_name='origin',
            name='Name',
            field=models.CharField(blank=True, db_index=True, max_length=100, null=True, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='region',
            name='RegionId',
            field=models.CharField(blank=True, db_index=True, max_length=100, null=True, verbose_name='位置'),
        ),
    ]
