# Generated by Django 4.0.2 on 2022-02-24 02:51

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='IDC',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('Name', models.CharField(blank=True, max_length=100, null=True, verbose_name='名称')),
                ('Idc', models.CharField(blank=True, max_length=100, null=True, verbose_name='简称')),
                ('Default',
                 models.CharField(blank=True, default='cn-beijing', max_length=100, null=True, verbose_name='默认区域')),
            ],
        ),
        migrations.CreateModel(
            name='Origin',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('CreateTime', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('ChangeTime', models.DateTimeField(auto_now=True, verbose_name='修改时间')),
                ('Sync', models.BooleanField(default=False)),
                ('Name', models.CharField(blank=True, max_length=100, null=True, verbose_name='Name')),
                ('AccessKeyId', models.CharField(blank=True, max_length=100, null=True, verbose_name='access Key Id')),
                (
                'AccessSecret', models.CharField(blank=True, max_length=1000, null=True, verbose_name='access Secret')),
                ('Remark', models.CharField(blank=True, max_length=100, null=True, verbose_name='备注信息')),
                ('Settings', models.JSONField(verbose_name='其他配置信息')),
                ('IDC', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='idc',
                                          to='cjtmc_base.idc')),
            ],
            options={
                'ordering': ('-CreateTime',),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Region',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('CreateTime', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('ChangeTime', models.DateTimeField(auto_now=True, verbose_name='修改时间')),
                ('Sync', models.BooleanField(default=False)),
                ('RegionId', models.CharField(blank=True, max_length=100, null=True, verbose_name='位置')),
                ('RegionEndpoint', models.CharField(blank=True, max_length=100, null=True, verbose_name='地域对应的接入地址')),
                ('LocalName', models.CharField(blank=True, max_length=100, null=True, verbose_name='地域名称')),
                ('OriginId', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                               to='cjtmc_base.origin')),
            ],
            options={
                'ordering': ('-CreateTime',),
                'abstract': False,
            },
        ),
    ]
