# Generated by Django 3.2.12 on 2022-03-02 02:04

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('cjtmc_base', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Env',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('CreateTime', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('ChangeTime', models.DateTimeField(auto_now=True, verbose_name='修改时间')),
                ('Sync', models.BooleanField(default=False)),
                ('Name', models.CharField(blank=True, max_length=100, null=True, verbose_name='名字')),
                ('Code', models.CharField(blank=True, max_length=100, null=True, unique=True, verbose_name='英文标识')),
                ('Status', models.BooleanField(default=1, verbose_name='环境是否可用')),
                ('Priority', models.IntegerField(default=0, help_text='优先级递增(0-10)', verbose_name='显示优先级')),
            ],
            options={
                'verbose_name': '环境数据表',
                'ordering': ('-Priority', 'Name'),
            },
        ),
    ]
